changeset 4313:8ec3036098df SDL-1.2

Adapted from Debian patch: 320_activate_xrandr_on_default.diff
author Sam Lantinga <slouken@libsdl.org>
date Sat, 10 Oct 2009 10:14:01 +0000
parents f2f8525e60c2
children 0660995cdd3b
files src/video/x11/SDL_x11modes.c
diffstat 1 files changed, 8 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/video/x11/SDL_x11modes.c	Sat Oct 10 10:10:36 2009 +0000
+++ b/src/video/x11/SDL_x11modes.c	Sat Oct 10 10:14:01 2009 +0000
@@ -421,11 +421,16 @@
         return 0;
     }
 
-    /* This defaults off now, due to KDE window maximize problems */
-    if ( !env ) {
+    /* This used to default off, due to KDE window maximize problems */
+    /* Reactivated since I haven't encountered such problems with KDE, but if
+       one does encounter such problems he/she can just set
+       SDL_VIDEO_X11_XRANDR to 0
+       Closes Debian bug: #450689
+     */
+/*  if ( !env ) {
         return 0;
     }
-
+*/
     if ( !SDL_X11_HAVE_XRANDR ) {
         return 0;
     }